@@ -1,4 +1,8 @@
-class NotFoundException(Exception):
+class BaseExceptionHandle(Exception):
+    def __init__(self, *args):
+        super(BaseExceptionHandle, self).__init__(*args)
+
+class NotFoundException(BaseExceptionHandle):
     """
     This exceptions indicates a client error : the object
     requested or subject to the requested operation does
@@ -6,21 +10,21 @@ class NotFoundException(Exception):
     """
     pass
 
-class InvalidDataException(Exception):
+class InvalidDataException(BaseExceptionHandle):
     """
     This exception indicates a client error : the
     data sent by the client are not valid.
     """
     pass
 
-class UnauthorizedException(Exception):
+class UnauthorizedException(BaseExceptionHandle):
     """
     This exception indicates that the client could not
     be authenticated.
     """
     pass
 
-class ForbiddenException(Exception):
+class ForbiddenException(BaseExceptionHandle):
     """
     This exception indicates that the client is not
     authorized to access the requested resource or
