@@ -153,7 +153,8 @@ def _get_default_swagger_path(route):
         return_value = _get_default_swagger_path_for_group_op_route(route)
     elif type(route) == routes.patch_resource_route:
         return_value = _get_default_swagger_path_for_patch_resource_route(route)
-
+    elif type(route) == routes.delete_resource_route:
+        return_value = _get_default_swagger_path_for_delete_resource_route(route)
     return return_value
 
 
@@ -163,7 +164,7 @@ def _get_default_swagger_path_for_get_route(route):
             "tags":[route.resource_class.resource_type],
             "summary": "Get by name".format(type=route.resource_class.resource_type),
             "description":"",
-            "operationId": "GET_{type}".format(type=route.resource_class.resource_type),
+            "operationId": "get{type}".format(type="_".join((unpluralize(x) for x in route.resource_class.resource_type.split("/")))),
             "produces": ["application/json"],
             "parameters": _get_parameters(route),
             "responses":{
@@ -196,7 +197,7 @@ def _get_default_swagger_path_for_get_all_route(route):
             "tags":[route.resource_class.resource_type],
             "summary": "Get all".format(type=route.resource_class.resource_type),
             "description":"",
-            "operationId": "GET_ALL_{type}".format(type=route.resource_class.resource_type),
+            "operationId": "get_all{type}".format(type="_".join(x for x in route.resource_class.resource_type.split("/"))),
             "produces": ["application/json"],
             "parameters": _get_parameters(route),
             "responses":{
@@ -229,12 +230,12 @@ def _get_default_swagger_path_for_put_route(route):
             "tags":[route.resource_class.resource_type],
             "summary": "Create or edit".format(type=route.resource_class.resource_type),
             "description":"",
-            "operationId": "PUT_{type}".format(type=route.resource_class.resource_type),
+            "operationId": "put{type}".format(type="_".join((unpluralize(x) for x in route.resource_class.resource_type.split("/")))),
             "produces": ["application/json"],
             "consumes": ["application/json"],
             "parameters": parameters,
             "responses":{
-                "200":
+                "201":
                 {
                     "description": "successful operation",
                     "schema":
@@ -262,11 +263,11 @@ def _get_default_swagger_path_for_patch_resource_route(route):
             "tags":[route.resource_class.resource_type],
             "summary": "Patch resource".format(type=route.resource_class.resource_type),
             "description":"",
-            "operationId": "PATCH_{type}".format(type=route.resource_class.resource_type),
+            "operationId": "patch{type}".format(type="_".join((unpluralize(x) for x in route.resource_class.resource_type.split("/")))),
             "produces": ["application/json"],
             "parameters": _get_parameters(route),
             "responses":{
-                "200":
+                "201":
                 {
                     "description": "successful operation",
                     "schema":
@@ -291,9 +292,9 @@ def _get_default_swagger_path_for_op_route(route):
     return_value = {
         "post":{
             "tags":[route.resource_class.resource_type],
-            "summary": "Operation {operation_name}".format(operation_name=route.operation_name, type=route.resource_class.resource_type),
+            "summary": "Operation {operation_name}".format(operation_name=route.operation_name),
             "description":"",
-            "operationId": "POST_{operation_name}_{type}".format(operation_name=route.operation_name, type=route.resource_class.resource_type),
+            "operationId": "{operation_name}{type}".format(operation_name=route.operation_name, type="_".join((unpluralize(x) for x in route.resource_class.resource_type.split("/")))),
             "produces": ["application/json"],
             "parameters": _get_parameters(route, route.operation_name),
             "responses":{
@@ -323,9 +324,9 @@ def _get_default_swagger_path_for_group_op_route(route):
     return_value = {
         "post":{
             "tags":[route.resource_class.resource_type],
-            "summary": "Group operation {operation_name}".format(operation_name=route.operation_name, type=route.resource_class.resource_type),
+            "summary": "Group operation {operation_name}".format(operation_name=route.operation_name),
             "description":"",
-            "operationId": "POST_GR_{operation_name}_{type}".format(operation_name=route.operation_name, type=route.resource_class.resource_type),
+            "operationId": "{operation_name}_all{type}".format(operation_name=route.operation_name, type="_".join(route.resource_class.resource_type.split("/"))),
             "produces": ["application/json"],
             "parameters": _get_parameters(route, route.operation_name),
             "responses":{
@@ -351,7 +352,37 @@ def _get_default_swagger_path_for_group_op_route(route):
 
     return return_value
 
+def _get_default_swagger_path_for_delete_resource_route(route):
+    return_value = {
+        "delete":{
+            "tags":[route.resource_class.resource_type],
+            "summary": "Delete ".format(type=route.resource_class.resource_type),
+            "description":"",
+            "operationId": "delete{type}".format(type="_".join((unpluralize(x) for x in route.resource_class.resource_type.split("/")))),
+            "produces": ["application/json"],
+            "parameters": _get_parameters(route),
+            "responses":{
+                "200":
+                {
+                    "description": "successful operation",
+                    "schema":
+                    {
+                        "$ref": "#/definitions/{type}".format(type=_get_swagger_type(route.resource_class)),
+                    }
+                },
+                "404":
+                {
+                    "description": "Not found: the requested {type} could not be found.".format(type=route.resource_class.resource_type),
+                    "schema":
+                    {
+                        "$ref": "#/definitions/error",
+                    }
+                }
+            }
+        }
+    }
 
+    return return_value
 #endregion
 
 
@@ -388,7 +419,7 @@ def _get_parameters(route, operation_name=None):
             "name":p.query_field,
             "in":"query",
             "required": not p.has_default,
-            "type": _get_parameter_type(p.type)
+            "type": _get_parameter_type(p.type),
         }, swagger_parameter_dict.get(p.query_field,{})) for p in query_decorators]
         parameters += [x for x in query_parameters if x is not None]
 
@@ -399,7 +430,6 @@ def _get_parameters(route, operation_name=None):
             "in":"header",
             "required": not p.has_default,
             "type": _get_parameter_type(p.type),
-            "description": swagger_parameter_dict.get(p.header_field)
         }, swagger_parameter_dict.get(p.header_field,{})) for p in header_decorators]
 
         parameters += [x for x in header_parameters if x is not None]
@@ -410,7 +440,8 @@ def _get_parameters(route, operation_name=None):
             merge({
                 "name":"body",
                 "in":"body",
-                "required": any(not p.has_default for p in body_parameters)
+                "required": any(not p.has_default for p in body_parameters),
+                "schema": {"type": "object"}
                 },
                 swagger_parameter_dict.get("body", {}))
             ]
@@ -507,4 +538,7 @@ def _update(d, u):
                 d[k] = v
         else:
             d[k] = v
-    return d
\ No newline at end of file
+    return d
+
+def unpluralize(word):
+    return word[:-3] + "y" if word [-3:] == "ies" else word[:-1]
\ No newline at end of file
