@@ -1,4 +1,5 @@
 import pytest
+import asyncio
 from collections import defaultdict
 
 @pytest.fixture
@@ -12,4 +13,13 @@ def loop(event_loop):
      If you comment this fixture out, default pytest-aiohttp one is used
      and things start failing (when redis pool is in place).
      """
-     return event_loop
\ No newline at end of file
+     return event_loop
+
+@pytest.fixture
+def make_coro():
+    def inner(obj):
+        mock_return_value = asyncio.Future()
+        mock_return_value.set_result(obj)
+        return mock_return_value
+
+    return inner
\ No newline at end of file
